[vlc-devel] commit: s/picture_Yield/picture_Hold/ (Antoine Cellerier )

git version control git at videolan.org
Sat Sep 20 22:32:14 CEST 2008


vlc | branch: master | Antoine Cellerier <dionoea at videolan.org> | Sat Sep 20 19:47:45 2008 +0200| [aeb8ac0199a5924a357414284ef119f868808022] | committer: Antoine Cellerier 

s/picture_Yield/picture_Hold/

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=aeb8ac0199a5924a357414284ef119f868808022
---

 include/vlc_vout.h                  |    6 +++---
 src/misc/image.c                    |    8 ++++----
 src/video_output/vout_subpictures.c |    2 +-
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/misc/image.c b/src/misc/image.c
index d9e60f2..826bcc8 100644
--- a/src/misc/image.c
+++ b/src/misc/image.c
@@ -316,7 +316,7 @@ static block_t *ImageWrite( image_handler_t *p_image, picture_t *p_pic,
             p_image->p_filter->fmt_out.video = p_image->p_enc->fmt_in.video;
         }
 
-        picture_Yield( p_pic );
+        picture_Hold( p_pic );
 
         p_tmp_pic =
             p_image->p_filter->pf_video_filter( p_image->p_filter, p_pic );
@@ -446,7 +446,7 @@ static picture_t *ImageConvert( image_handler_t *p_image, picture_t *p_pic,
         p_image->p_filter->fmt_out.video = *p_fmt_out;
     }
 
-    picture_Yield( p_pic );
+    picture_Hold( p_pic );
 
     p_pif = p_image->p_filter->pf_video_filter( p_image->p_filter, p_pic );
 
@@ -493,7 +493,7 @@ static picture_t *ImageFilter( image_handler_t *p_image, picture_t *p_pic,
         p_image->p_filter->fmt_out.video = *p_fmt;
     }
 
-    picture_Yield( p_pic );
+    picture_Hold( p_pic );
 
     return p_image->p_filter->pf_video_filter( p_image->p_filter, p_pic );
 }
@@ -587,7 +587,7 @@ static void video_del_buffer( decoder_t *p_dec, picture_t *p_pic )
 static void video_link_picture( decoder_t *p_dec, picture_t *p_pic )
 {
     (void)p_dec;
-    picture_Yield( p_pic );
+    picture_Hold( p_pic );
 }
 
 static void video_unlink_picture( decoder_t *p_dec, picture_t *p_pic )
diff --git a/src/video_output/vout_subpictures.c b/src/video_output/vout_subpictures.c
index e7eacf1..6988b0e 100644
--- a/src/video_output/vout_subpictures.c
+++ b/src/video_output/vout_subpictures.c
@@ -1061,7 +1061,7 @@ static void SpuRenderRegion( spu_t *p_spu,
             filter_t *p_scale = p_spu->p_scale;
 
             picture_t *p_picture = p_region->p_picture;
-            picture_Yield( p_picture );
+            picture_Hold( p_picture );
 
             /* Convert YUVP to YUVA/RGBA first for better scaling quality */
             if( b_using_palette )




More information about the vlc-devel mailing list
diff --git a/include/vlc_vout.h b/include/vlc_vout.h
index b3b2afd..f07bc6f 100644
--- a/include/vlc_vout.h
+++ b/include/vlc_vout.h
@@ -126,7 +126,7 @@ struct picture_t
 /**
  * This function will create a new picture.
  * The picture created will implement a default release management compatible
  * with picture_Yield and picture_Release. This default management will release
  * picture_sys_t *p_sys field if non NULL.
  */
 VLC_EXPORT( picture_t *, picture_New, ( vlc_fourcc_t i_chroma, int i_width, int i_height, int i_aspect ) );
@@ -144,7 +144,7 @@ VLC_EXPORT( void, picture_Delete, ( picture_t * ) );
  * This function will increase the picture reference count.
  * It will not have any effect on picture obtained from vout
  */
-static inline void picture_Yield( picture_t *p_picture )
+static inline void picture_Hold( picture_t *p_picture )
 {
     if( p_picture->pf_release )
         p_picture->i_refcount++;
@@ -196,7 +196,7 @@ VLC_EXPORT( void, plane_CopyPixels, ( plane_t *p_dst, const plane_t *p_src ) );
 
 /**
  * This function will copy both picture dynamic properties and pixels.
  * You have to notice that sometime a simple picture_Yield may do what
  * you want without the copy overhead.
  * Provided for convenience.
  */
@@ -126,7 +126,7 @@ struct picture_t
  * This function will create a new picture.
  * The picture created will implement a default release management compatible
- * with picture_Yield and picture_Release. This default management will release
+ * with picture_Hold and picture_Release. This default management will release
  * picture_sys_t *p_sys field if non NULL.
  */
@@ -196,7 +196,7 @@ VLC_EXPORT( void, plane_CopyPixels, ( plane_t *p_dst, const plane_t *p_src ) );
 /**
  * This function will copy both picture dynamic properties and pixels.
- * You have to notice that sometime a simple picture_Yield may do what
+ * You have to notice that sometime a simple picture_Hold may do what
  * you want without the copy overhead.
  * Provided for convenience.